@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from django.db import models
 
 from bleach import clean
@@ -33,16 +34,17 @@ class BleachField(models.TextField):
 
         # If field doesn't have any choice return BleachField
         if not self.choices:
-            return forms.BleachField(
-                label=self.verbose_name,
-                max_length=self.max_length,
-                allowed_tags=self.bleach_kwargs.get("tags"),
-                allowed_attributes=self.bleach_kwargs.get("attributes"),
-                allowed_styles=self.bleach_kwargs.get("styles"),
-                allowed_protocols=self.bleach_kwargs.get("protocols"),
-                strip_tags=self.bleach_kwargs.get("strip"),
-                strip_comments=self.bleach_kwargs.get("strip_comments"),
-            )
+            kwargs.update({
+                "max_length": self.max_length,
+                "allowed_tags": self.bleach_kwargs.get("tags"),
+                "allowed_attributes": self.bleach_kwargs.get("attributes"),
+                "allowed_styles": self.bleach_kwargs.get("styles"),
+                "allowed_protocols": self.bleach_kwargs.get("protocols"),
+                "strip_tags": self.bleach_kwargs.get("strip"),
+                "strip_comments": self.bleach_kwargs.get("strip_comments"),
+                "required": not self.blank,
+            })
+            return forms.BleachField(**kwargs)
 
         return super(BleachField, self).formfield(**kwargs)
 
